#
# spec file for package QtAV
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.links2linux.org/
#


%define sover 1
%define ffmpeg_includedir -I%(pkg-config --variable=includedir libavutil)
Name:           QtAV
Version:        1.12.0
Release:        1.3
Summary:        Qt multimedia framework
License:        LGPL-2.1+ and GPL-3.0
Group:          Productivity/Multimedia/Other
Url:            http://qtav.org/
Source0:        https://github.com/wang-bin/QtAV/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  ImageMagick
BuildRequires:  dos2unix
BuildRequires:  hicolor-icon-theme
BuildRequires:  kf5-filesystem
BuildRequires:  pkgconfig
BuildRequires:  portaudio-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5Qml)
BuildRequires:  pkgconfig(Qt5Quick)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(libass)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavdevice)
BuildRequires:  pkgconfig(libavfilter)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavresample)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libpulse) >= 1.0
BuildRequires:  pkgconfig(libswresample)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(libva)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(uchardet)
BuildRequires:  pkgconfig(xv)
Provides:       Qt5AV = %{version}
Obsoletes:      Qt5AV < %{version}
Requires:       %{name}-players = %{version}

%description
QtAV is a multimedia playback library based on Qt and FFmpeg. It can help
you to write a player with less effort than ever before.

Features include:
    * Hardware decoding suppprt: DXVA2, VAAPI, VDA, CedarX, CUDA
    * OpenGL and ES2 support for Hi10P and other 16-bit YUV videos
    * Real time preview
    * Video capture in rgb and yuv format
    * OSD and custom filters
    * Subtitle
    * Transform video using GraphicsItemRenderer. (rotate, shear, etc)
    * Playing frame by frame (currently support forward playing)
    * Playback speed control
    * Variant streams: locale file, http, rtsp, etc.
    * Audio channel, tracks and external audio tracks
    * Dynamically change render engine when playing
    * Multiple video outputs for 1 player
    * Region of interest(ROI), i.e. video cropping
    * Video eq: brightness, contrast, saturation, hue
    * QML support as a plugin. Most playback APIs are compatible with
      QtMultiMedia module

%package -n     lib%{name}%{sover}
Summary:        QtAV library
Group:          System/Libraries

%description -n lib%{name}%{sover}
QtAV is a multimedia playback library based on Qt and FFmpeg.

This package contains the QtAV library.

%package -n     lib%{name}Widgets%{sover}
Summary:        QtAV Widgets module
Group:          System/Libraries
Requires:       libQt5OpenGL5

%description -n lib%{name}Widgets%{sover}
QtAV is a multimedia playback library based on Qt and FFmpeg.

This package contains a set of widgets to play media.

%package        qml
Summary:        QtAV QML module
Group:          Productivity/Multimedia/Other

%description    qml
QtAV is a multimedia playback library based on Qt and FFmpeg.

This package contains the QtAV QML module for Qt declarative.

%package -n     %{name}-players
Summary:        QtAV/QML players
Group:          Productivity/Multimedia/Video/Players
Requires:       %{name}-qml = %{version}
Requires:       lib%{name}Widgets%{sover} = %{version}
Requires:       libqt5-qtquickcontrols

%description -n	%{name}-players
QtAV is a multimedia playback library based on Qt and FFmpeg.

This package contains the QtAV based players.

%package        devel
Summary:        QtAV development files
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{sover} = %{version}
Requires:       lib%{name}Widgets%{sover} = %{version}
Requires:       libQt5OpenGL-devel

%description    devel
QtAV is a multimedia playback library based on Qt and FFmpeg.

This package contains the header development files for building some QtAV
applications using QtAV headers.

%prep
%setup -q

# Fix incorrect sRGB profile
for f in $(find . -type f -name \*.png); do
convert $f -strip $f
done

BUILD_TIME=$(LC_ALL=C date -ur %{_sourcedir}/%{name}.changes +'%H:%M')
BUILD_DATE=$(LC_ALL=C date -ur %{_sourcedir}/%{name}.changes +'%b %d %Y')
grep -rl '__TIME__' . | xargs --verbose --no-run-if-empty \
sed -i "s/__TIME__/\"$BUILD_TIME\"/"
grep -rl '__DATE__' . | xargs --verbose --no-run-if-empty \
sed -i "s/__DATE__/\"$BUILD_DATE\"/"

find . -type f -name \*.pro | while read FILE; do
echo "QMAKE_CXXFLAGS_RELEASE += %{ffmpeg_includedir}" >> "$FILE"; done

%build
mkdir build
pushd build
%qmake5 "CONFIG+=no_rpath recheck" ../%{name}.pro
%make_jobs PREFIX=%{_prefix}
popd

%install
pushd build
%qmake5_install
popd

install -d %{buildroot}%{_bindir}
ln -s %{_libqt5_bindir}/Player %{buildroot}%{_bindir}/Player
ln -s %{_libqt5_bindir}/QMLPlayer %{buildroot}%{_bindir}/QMLPlayer

find %{buildroot} -name \*.a -exec rm {} \;

# Duplicate files
rm -rf  %{buildroot}%{_datadir}/doc

printf 'lib%{name}%{sover}\n
lib%{name}Widgets%{sover}\n' > %{_sourcedir}/baselibs.conf

%post -n  lib%{name}%{sover} -p /sbin/ldconfig
%postun -n  lib%{name}%{sover} -p /sbin/ldconfig

%post -n lib%{name}Widgets%{sover} -p /sbin/ldconfig
%postun -n lib%{name}Widgets%{sover} -p /sbin/ldconfig

%post -n %{name}-players 
%icon_theme_cache_post
%desktop_database_post

%postun -n %{name}-players
%icon_theme_cache_postun
%desktop_database_postun

%files
%defattr(-,root,root)
%doc Changelog gpl-3.0* lgpl-2.1* README*

%files -n lib%{name}%{sover}
%defattr(-,root,root)
%{_libqt5_libdir}/lib%{name}.so.*

%files -n lib%{name}Widgets%{sover}
%defattr(-,root,root)
%{_libqt5_libdir}/lib%{name}Widgets.so.*

%files qml
%defattr(-,root,root)
%dir %{_kf5_qmldir}/%{name}
%{_kf5_qmldir}/%{name}/Video.qml
%{_kf5_qmldir}/%{name}/libQmlAV.so
%{_kf5_qmldir}/%{name}/plugins.qmltypes
%{_kf5_qmldir}/%{name}/qmldir

%files -n %{name}-players
%defattr(-,root,root)
%{_bindir}/Player
%{_bindir}/QMLPlayer
%{_libqt5_bindir}/Player
%{_libqt5_bindir}/QMLPlayer
%{_datadir}/applications/Player.desktop
%{_datadir}/applications/QMLPlayer.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.??g

%files devel
%defattr(-,root,root)
%{_libqt5_libdir}/lib%{name}.so
%{_libqt5_libdir}/lib%{name}.prl
%{_libqt5_libdir}/lib%{name}Widgets.so
%{_libqt5_libdir}/lib%{name}Widgets.prl
%{_libqt5_archdatadir}/mkspecs/features/av.prf
%{_libqt5_archdatadir}/mkspecs/features/avwidgets.prf
%{_kf5_mkspecsdir}/qt_lib_av.pri
%{_kf5_mkspecsdir}/qt_lib_av_private.pri
%{_kf5_mkspecsdir}/qt_lib_avwidgets.pri
%{_kf5_mkspecsdir}/qt_lib_avwidgets_private.pri
%{_libqt5_includedir}/QtAV/
%{_libqt5_includedir}/QtAVWidgets/

%changelog
* Thu Jun 22 2017 avvissu@yandex.by
- Update to 1.12.0:
  * see: /usr/share/doc/packages/QtAV/ChangeLog
* Wed Feb  8 2017 avvissu@yandex.by
- Update to 0.11.0:
  * see: /usr/share/doc/packages/QtAV/ChangeLog
- Add BuildRequires: pkgconfig(Qt5Sql)
- Spec file cleanup
* Wed Mar  2 2016 avvissu@yandex.ru
- Fix desktopfile-without-binary
* Wed Mar  2 2016 avvissu@yandex.ru
- Update to 1.10.0:
  * see: /usr/share/doc/packages/QtAV/ChangeLog
* Mon Dec 21 2015 avvissu@yandex.ru
- Update to 1.9.0:
  * see: /usr/share/doc/packages/QtAV/ChangeLog
- Remove patches:
  * QtAV-1.8.0_link_libraries.patch (fixed in upstream)
* Thu Dec 10 2015 avvissu@yandex.ru
- Fix build errors with ffmpeg: define ffmpeg_includedir
* Tue Sep 22 2015 olaf@aepfle.de
- Use pkgconfig for some BuildRequires
* Sun Sep 13 2015 avvissu@yandex.ru
- Use predefined RPM macros from /etc/rpm/macros.qt5
- Add QtAV-1.8.0_link_libraries.patch
- Add BuildRequires: kf5-filesystem
* Wed Sep  2 2015 avvissu@yandex.ru
- Update to 1.8.0:
  * see: /usr/share/doc/packages/QtAV/ChangeLog
- Remove QtAV-1.6.0_qreal.patch (fixed in upstream)
* Thu Jun 11 2015 avvissu@yandex.ru
- Fix build on openSUSE > 13.2:
  * use original name of project (Qt5AV -> QtAV)
* Sat May 30 2015 avvissu@yandex.ru
- Add conflicts: %%%%name-players for different Qt versions
- Execute %%%%desktop_database_post(postun) only for %%%%name-players
* Wed May  6 2015 avvissu@yandex.ru
- Fix files is compiled without RPM_OPT_FLAG
* Sun Apr 26 2015 avvissu@yandex.ru
- Fix build on arm (QtAV-1.6.0_qreal.patch)
- Fix incorrect sRGB profile
- Drop QtAV-1.5.0_rpath.patch (fixed)
* Sat Apr 25 2015 avvissu@yandex.ru
- Update to 1.6.0:
- OpenGL:
  * PBO support (enable by enviroment var QTAV_PBO=1)
  * rectangle texture support
  * packed yuv formats support
  * support buffer progress, buffer value control
- Support frame rate setup
- Support RAW streams, such as h264, yuv
- Audio filter support
- Better libavfilter support
- Add pulseaudio support
- Detect volume change by per-app volume control
- player/QMLPlayer:
  * decoder detail
  * more options: preview config, buffer, fps, timeout
- Use CONFIG+=no_rpath instead of QtAV-1.5.0_rpath.patch
* Wed Apr  1 2015 avvissu@yandex.ru
- Build with Qt4 on openSUSE < 13.2:
  * change QtAV.spec for build with Qt4
  * add BuildRequires: libqt4-devel
- Add Qt5AV.spec:
  * [fixed] module "QtQuick.Dialogs" is not installed:
  add Requires: libqt5-qtquickcontrols Qt5AV-qml
- Fix error while loading shared libraries:
  * change QtAV-1.5.0_rpath.patch
  * set the environment variable $BINDIR and $QMLDIR
- Add 32-bit packages for 64-bit environment
* Sun Mar 29 2015 avvissu@yandex.ru
- Initial release
